@@ -30,11 +30,15 @@ future_xapply <- local({
     ## Support %globals%, %packages%, %seed%, ...
     ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     opts <- getOption("future.disposable", NULL)
-    for (name in names(opts)) {
-      var <- sprintf("future.%s", name)
-      assign(var, opts[[name]], envir = environment(), inherits = FALSE)
+    if (length(opts) > 0) {
+      for (name in names(opts)) {
+        var <- sprintf("future.%s", name)
+        assign(var, opts[[name]], envir = environment(), inherits = FALSE)
+      }
+      if (!identical(attr(opts, "dispose"), FALSE)) {
+        options(future.disposable = NULL)
+      }
     }
-    options(future.disposable = NULL)
 
 
     ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
